@@ -64,11 +64,11 @@ extern "C" {
         TSK_FS_BLOCK_FLAG_UNALLOC = 0x0002,     ///< Block is unallocated (and not TSK_FS_BLOCK_FLAG_ALLOC)
         TSK_FS_BLOCK_FLAG_CONT = 0x0004,        ///< Block (could) contain file content (and not TSK_FS_BLOCK_FLAG_META)
         TSK_FS_BLOCK_FLAG_META = 0x0008,        ///< Block (could) contain file system metadata (and not TSK_FS_BLOCK_FLAG_CONT)
-        TSK_FS_BLOCK_FLAG_RAW = 0x0010, ///< The data has been read raw from the disk and is not compressed, encrypted, sparse etc.
-        TSK_FS_BLOCK_FLAG_BAD = 0x0020, ///< Block has been marked as bad by the file system
-        TSK_FS_BLOCK_FLAG_RES = 0x0040, ///< The data passed in the file_walk callback is from an NTFS resident file
-        TSK_FS_BLOCK_FLAG_SPARSE = 0x0080,      ///< The data passed in the file_walk calback was stored as sparse (all zeros)
-        TSK_FS_BLOCK_FLAG_COMP = 0x0100 ///< The data passed in the file_walk callback was stored in a compressed form
+        TSK_FS_BLOCK_FLAG_BAD = 0x0010, ///< Block has been marked as bad by the file system
+        TSK_FS_BLOCK_FLAG_RAW = 0x0020, ///< The data has been read raw from the disk (and not COMP or SPARSE)
+        TSK_FS_BLOCK_FLAG_SPARSE = 0x0040,      ///< The data passed in the file_walk calback was stored as sparse (all zeros) (and not RAW or COMP)
+        TSK_FS_BLOCK_FLAG_COMP = 0x0080,        ///< The data passed in the file_walk callback was stored in a compressed form (and not RAW or SPARSE)
+        TSK_FS_BLOCK_FLAG_RES = 0x0100  ///< The data passed in the file_walk callback is from an NTFS resident file
     };
     typedef enum TSK_FS_BLOCK_FLAG_ENUM TSK_FS_BLOCK_FLAG_ENUM;
 
@@ -407,7 +407,6 @@ extern "C" {
      */
     typedef struct {
         int tag;                ///< \internal Will be set to TSK_FS_META_TAG if structure is allocated
-        TSK_FS_INFO *fs_info;   ///< Pointer to file system that file is located in.
 
         TSK_FS_META_FLAG_ENUM flags;    ///< Flags for this file for its allocation status etc.
         TSK_INUM_T addr;        ///< Address of the meta data structure for this file
@@ -525,7 +524,7 @@ extern "C" {
         char *name;             ///< The name of the file (in UTF-8)
         size_t name_size;       ///< The number of bytes allocated to name
 
-        char *shrt_name;        ///< The short name of the file (FAT and NTFS only) or null (in UTF-8)
+        char *shrt_name;        ///< The short name of the file or null (in UTF-8)
         size_t shrt_name_size;  ///< The number of bytes allocated to shrt_name
 
         TSK_INUM_T meta_addr;   ///< Address of the metadata structure that the name points to. 
